pub enum PackError {
BufferTooSmall {
need: usize,
},
InvalidPayloadSize {
expected: usize,
found: usize,
},
MarshalerError(MarshalerError),
}Expand description
Errors returned by Messager::pack.
Variants
BufferTooSmall
The destination buffer is too small to hold the complete frame.
Fields
InvalidPayloadSize
The marshaler returned a byte count that does not equal
Marshaler::PAYLOAD_SIZE.
This indicates a broken Marshaler implementation.
Fields
MarshalerError(MarshalerError)
The marshaler returned an error.